@@ -35,9 +35,7 @@ try:
     from . import _version
     __version__ = _version.version.split('.dev')[0]
 except ImportError:
-    __version__ = '0.1.8rc1' 
-finally:
-    __author__= 'L.Kouadio'
+    __version__ = '0.2.0' 
 
 # # set loging Level
 logging.getLogger(__name__)#.setLevel(logging.WARNING)
@@ -153,7 +151,8 @@ from .utils import (
     plotAnomaly, 
     vesSelector, 
     erpSelector, 
-    read_data, 
+    read_data,
+    cleaner, 
     erpSmartDetector,
     type_,
     shape, 
@@ -188,8 +187,6 @@ from .utils import (
     plot_confidence_in,
     qc,
     )
-# may useful to fix 
-# circular import
 try : 
     from .utils import ( 
         selectfeatures, 
@@ -324,5 +321,6 @@ __all__ = [
     "make_naive_pipe", 
     "bi_selector", 
     "show_versions",
+    "cleaner", 
     ]
 
