@@ -37,11 +37,14 @@ from .exmath import (
     get_full_frequency, 
     get_strike, 
     get_profile_angle, 
+    get_bearing, 
     moving_average, 
     linkage_matrix, 
     plotOhmicArea, 
     plot_confidence_in,
-    plot_sfi
+    plot_sfi, 
+    get_distance,
+    qc, 
     )
 from .funcutils import ( 
     reshape, 
@@ -49,6 +52,8 @@ from .funcutils import (
     smart_label_classifier, 
     remove_outliers,
     normalizer, 
+    cleaner, 
+    savejob
     )
 from .hydroutils import ( 
     select_base_stratum , 
@@ -88,8 +93,6 @@ from .plotutils import (
     plot_skew, 
     plot_strike,
     )
-# to fix circular 
-# import
 try : 
     from .mlutils import ( 
         selectfeatures, 
@@ -107,6 +110,7 @@ try :
         select_feature_importances, 
         make_naive_pipe, 
         bi_selector, 
+        get_target, 
         )
 except ImportError :pass 
 
@@ -194,6 +198,12 @@ __all__=[
         'remove_outliers', 
         'normalizer',
         'plot_strike',
+        'get_target', 
+        'get_distance',
+        'get_bearing', 
+        'qc', 
+        'cleaner', 
+        'savejob'
         ]
 
 
